@@ -1,6 +1,6 @@
 package MARC::Moose::Parser;
 # ABSTRACT: A record parser base class
-$MARC::Moose::Parser::VERSION = '1.0.27';
+$MARC::Moose::Parser::VERSION = '1.0.28';
 use Moose;
 use Modern::Perl;
 
@@ -12,7 +12,7 @@ use Modern::Perl;
 #);
 
 
-has lint => (is => 'rw', isa => 'MARC::Moose::Lint::Checker');
+has lint => (is => 'rw');
 
 
 
@@ -48,7 +48,7 @@ MARC::Moose::Parser - A record parser base class
 
 =head1 VERSION
 
-version 1.0.27
+version 1.0.28
 
 =head1 METHODS
 
